logging

package
v0.0.0-...-f688354 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 23, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package logging provides a factory for creating configured zap loggers.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewLogger

func NewLogger(level, format, filePath string) (*zap.Logger, error)

NewLogger creates a zap.Logger configured with the given level, format, and optional file path. If filePath is empty, logs go to stderr only.

Types

This section is empty.

Jump to